#ifndef INC_GTCOLORMAP_H
#define INC_GTCOLORMAP_H

#include <X11/Xlib.h>

#include "gtbase.h"
#include "gtdisplay.h"

/************************************************************************\
*
* GtColormap class header.
*
* $Ident: This file is part of the 'Gt-library' 1.0.0 $
* $Copyright: (C) 1997 by Gran Gustafsson $
*
\************************************************************************/

/* Modes of colormap allocation */
#define GTCM_DEFAULT		0
#define GTCM_ALLOCALL		1
#define GTCM_ALLOCNONE	2

class GtColormap : public GtBase
{
public:
		/* Standard */
	GtColormap(void);
	void Destroy(void);
	sbool Init(GtDisplay *d,GtTag *tgs);
	sbool Init(GtTag *tgs);
	sbool Set(GtTag *tgs);
	void Get(GtTag *tgs);
	char *GetClass(void) { return("GtColormap"); }
	sbool IsSubClassOf(char *cn);
		/* Allocs */
	sbool AllocC(XColor *rgb);
	sbool AllocC(ulong *pix,uword r,uword g,uword b);
	sbool AllocNamedC(char *name,XColor *rgb);
	sbool AllocCells(ulong *cells,int nr,sbool cont);
	void FreeC(ulong pix);
		/* Store */
	void StoreC(XColor *rgb);
	void StoreC(ulong pix,uword r,uword g,uword b);
	void StoreNamedC(char *name,ulong pix);
		/* Queries */
	void QueryC(XColor *rgb);
	sbool FindNamedC(char *name,XColor *rgb,XColor *trgb);
		/* Values */
	inline Colormap XCm(void) { return(cm); }
protected:
	GtDisplay *dsp;
	Visual *vis;
	Colormap cm;
	ubyte mode;
	sbool nofreex;
};

extern GtColormap *GtMkColormap(GtDisplay *d,GtTag *tgs);
extern GtColormap *GtMkColormap(GtDisplay *d,ulong tag,...);

#endif /* INC_GTCOLORMAP_H */
